@@ -259,10 +259,12 @@ void hide_in_win(ClientState *cs)
     case 3:
       hide_win_pho();
       break;
+#if USE_TSIN
     case 6:
 //      flush_tsin_buffer();
       hide_win0();
       break;
+#endif
     case 10:
       hide_win_int();
       break;
@@ -294,9 +296,11 @@ void show_in_win(ClientState *cs)
     case 3:
       show_win_pho();
       break;
+#if USE_TSIN
     case 6:
       show_win0();
       break;
+#endif
     case 10:
       show_win_int();
       break;
@@ -341,9 +345,11 @@ void move_in_win(ClientState *cs, int x, int y)
     case 3:
       move_win_pho(x, y);
       break;
+#if USE_TSIN
     case 6:
       move_win0(x, y);
       break;
+#endif
     case 10:
       move_win_int(x, y);
       break;
@@ -466,9 +472,11 @@ void disp_im_half_full()
     case 3:
       win_pho_disp_half_full();
       break;
+#if USE_TSIN
     case 6:
       win_tsin_disp_half_full();
       break;
+#endif
     default:
       win_gtab_disp_half_full();
       break;
@@ -478,6 +486,15 @@ void disp_im_half_full()
 gboolean flush_tsin_buffer();
 void reset_gtab_all();
 
+static u_int orig_caps_state;
+
+void init_state_chinese(ClientState *cs)
+{
+  cs->im_state = GCIN_STATE_CHINESE;
+  if (!cs->in_method)
+    init_in_method(default_input_method);
+}
+
 void toggle_im_enabled(u_int kev_state)
 {
 //    dbg("toggle_im_enabled\n");
@@ -486,7 +503,6 @@ void toggle_im_enabled(u_int kev_state)
     if (current_CS->in_method < 0 || current_CS->in_method > MAX_GTAB_NUM_KEY)
       p_err("err found");
 
-    static u_int orig_caps_state;
 
     if (current_CS->im_state != GCIN_STATE_DISABLED) {
       if (current_CS->in_method== 6 && (kev_state & LockMask) != orig_caps_state &&
@@ -518,12 +534,9 @@ void toggle_im_enabled(u_int kev_state)
       update_tray_icon();
 #endif
     } else {
-      current_CS->im_state = GCIN_STATE_CHINESE;
-      orig_caps_state = kev_state & LockMask;
+      init_state_chinese(current_CS);
 
-      if (!current_CS->in_method) {
-        init_in_method(default_input_method);
-      }
+      orig_caps_state = kev_state & LockMask;
 
       reset_current_in_win_xy();
 #if 1
@@ -533,10 +546,7 @@ void toggle_im_enabled(u_int kev_state)
       update_in_win_pos();
       show_in_win(current_CS);
 #endif
-#if 0
-      if (gcin_pop_up_win)
-        show_win_stautus();
-#endif
+
 #if TRAY_ENABLED
       update_tray_icon();
 #endif
@@ -554,9 +564,11 @@ void update_active_in_win_geom()
     case 3:
       get_win_pho_geom();
       break;
+#if USE_TSIN
     case 6:
       get_win0_geom();
       break;
+#endif
     case 10:
       break;
     default:
@@ -642,10 +654,12 @@ gboolean init_in_method(int in_no)
       current_CS->in_method = in_no;
       init_tab_pho();
       break;
+#if USE_TSIN
     case 6:
       current_CS->in_method = in_no;
       init_tab_pp(True);
       break;
+#endif
     case 10:
       current_CS->in_method = in_no;
       init_inter_code(True);
@@ -720,6 +734,10 @@ gboolean timeout_raise_window()
 }
 
 
+gboolean control_punc(KeySym keysym)
+{
+}
+
 // return TRUE if the key press is processed
 gboolean ProcessKeyPress(KeySym keysym, u_int kev_state)
 {
@@ -768,7 +786,10 @@ gboolean ProcessKeyPress(KeySym keysym, u_int kev_state)
 
 
   if ((kev_state & (Mod1Mask|ShiftMask)) == (Mod1Mask|ShiftMask)) {
-    return feed_phrase(keysym, kev_state);
+    if (current_CS->im_state != GCIN_STATE_DISABLED || gcin_eng_phrase_enabled)
+      return feed_phrase(keysym, kev_state);
+    else
+      return 0;
   }
 
 //  dbg("state %x\n", kev_state);
@@ -819,11 +840,18 @@ gboolean ProcessKeyPress(KeySym keysym, u_int kev_state)
     timeout_handle = g_timeout_add(200, timeout_raise_window, NULL);
   }
 
+  if (kev_state & ControlMask) {
+    if (feed_phrase(keysym, kev_state))
+      return TRUE;
+  }
+
   switch(current_CS->in_method) {
     case 3:
       return feedkey_pho(keysym, kev_state);
+#if USE_TSIN
     case 6:
       return feedkey_pp(keysym, kev_state);
+#endif
     case 10:
       return feedkey_intcode(keysym);
     default:
@@ -844,10 +872,12 @@ gboolean ProcessKeyRelease(KeySym keysym, u_int kev_state)
   if (current_CS->im_state == GCIN_STATE_DISABLED)
     return FALSE;
 
+#if USE_TSIN
   switch(current_CS->in_method) {
     case 6:
       return feedkey_pp_release(keysym, kev_state);
   }
+#endif
 
   return FALSE;
 }
@@ -900,6 +930,8 @@ int gcin_FocusIn(ClientState *cs)
 
   current_CS = cs;
 
+//  dbg("current_CS %x %d %d\n", cs, cs->im_state, current_CS->im_state);
+
   if (win == focus_win) {
     if (cs->im_state != GCIN_STATE_DISABLED) {
 #if 0
