@@ -7,7 +7,7 @@ int gcin_remote_client;
 int default_input_method;
 int left_right_button_tips;
 int gcin_im_toggle_keys;
-int gcin_capslock_lower;
+int gcin_capslock_lower, gcin_eng_phrase_enabled, gcin_init_im_enabled;
 
 int gtab_dup_select_bell;
 int gtab_space_auto_first;
@@ -25,12 +25,14 @@ int gtab_in_row1;
 int gtab_capslock_in_eng;
 int gtab_vertical_select;
 int gtab_unique_auto_send;
-
+int gtab_que_wild_card;
 
 int tsin_phrase_pre_select, tsin_tone_char_input;
 int tsin_capslock_upper;
 int phonetic_char_dynamic_sequence;
 int phonetic_huge_tab;
+int phonetic_speak;
+char *phonetic_speak_sel;
 int tsin_chinese_english_toggle_key;
 int gcin_font_size_tsin_pho_in;
 int pho_simple_win;
@@ -67,6 +69,8 @@ void load_setttings()
   gcin_root_y = get_gcin_conf_int(GCIN_ROOT_Y, 2000);
   gcin_pop_up_win = get_gcin_conf_int(GCIN_POP_UP_WIN, 1);
   gcin_inner_frame = get_gcin_conf_int(GCIN_INNER_FRAME, 0);
+  gcin_eng_phrase_enabled = get_gcin_conf_int(GCIN_ENG_PHRASE_ENABLED, 1);
+  gcin_init_im_enabled = get_gcin_conf_int(GCIN_INIT_IM_ENABLED, 0);
 #if GTK_MAJOR_VERSION >=2 && GTK_MINOR_VERSION >= 4
 #define ABS_VAL 0
 #else
@@ -103,6 +107,7 @@ void load_setttings()
   gtab_capslock_in_eng = get_gcin_conf_int(GTAB_CAPSLOCK_IN_ENG, 1);
   gtab_vertical_select = get_gcin_conf_int(GTAB_VERTICAL_SELECT, 0);
   gtab_unique_auto_send = get_gcin_conf_int(GTAB_UNIQUE_AUTO_SEND, 0);
+  gtab_que_wild_card = get_gcin_conf_int(GTAB_QUE_WILD_CARD, 0);
 
   tsin_phrase_pre_select = get_gcin_conf_int(TSIN_PHRASE_PRE_SELECT, 1);
   tsin_chinese_english_toggle_key = get_gcin_conf_int(TSIN_CHINESE_ENGLISH_TOGGLE_KEY,
@@ -117,6 +122,8 @@ void load_setttings()
 
   phonetic_char_dynamic_sequence = get_gcin_conf_int(PHONETIC_CHAR_DYNAMIC_SEQUENCE, 1);
   phonetic_huge_tab = get_gcin_conf_int(PHONETIC_HUGE_TAB, 0);
+  phonetic_speak = get_gcin_conf_int(PHONETIC_SPEAK, 0);
+  get_gcin_conf_str(PHONETIC_SPEAK_SEL, &phonetic_speak_sel, "1");
 
   pho_hide_row2 = get_gcin_conf_int(PHO_HIDE_ROW2, 0);
   pho_in_row1 = get_gcin_conf_int(PHO_IN_ROW1, 1);
