@@ -1,6 +1,8 @@
 #include <signal.h>
 // #include <openssl/ssl.h>
 #include "gcin.h"
+#include "config.h"
+#include <libintl.h>
 
 Display *dpy;
 Window root;
@@ -42,10 +44,12 @@ void start_inmd_window()
       create_win_pho();
       xim_arr[0].xim_xwin = xwin_pho;
       break;
+#if USE_TSIN
     case 6:
       create_win0();
       xim_arr[0].xim_xwin = xwin0;
       break;
+#endif
     default:
       create_win_gtab();
       xim_arr[0].xim_xwin = xwin_gtab;
@@ -417,11 +421,18 @@ void do_exit()
 
 char *get_gcin_xim_name();
 void load_phrase(), init_TableDir(),  load_gtab_list();
-void init_im_serv(), create_tray();
+void init_im_serv(), init_tray();
 void init_gcin_im_serv(Window win);
 
 int main(int argc, char **argv)
 {
+
+#if GCIN_i18n_message
+  gtk_set_locale();
+  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+  textdomain(GETTEXT_PACKAGE);
+#endif
+
 #if USE_XIM
   char *lc_ctype = getenv("LC_CTYPE");
   char *lc_all = getenv("LC_ALL");
@@ -503,8 +514,9 @@ int main(int argc, char **argv)
 #endif
 
 #if TRAY_ENABLED
-  if (gcin_status_tray)
-    create_tray();
+  if (gcin_status_tray) {
+    init_tray();
+  }
 #endif
 
   gtk_main();
