@@ -107,7 +107,7 @@ static int qcmp_strlen(const void *aa, const void *bb)
 
 #define Max_tab_key_num1(inm) (inm->key64 ? MAX_TAB_KEY_NUM64 : MAX_TAB_KEY_NUM)
 #define Max_tab_key_num Max_tab_key_num1(cur_inmd)
-void set_key_codes_label(char *s);
+void set_key_codes_label(char *s, int better);
 void set_page_label(char *s);
 
 static void clear_page_label()
@@ -115,9 +115,9 @@ static void clear_page_label()
   set_page_label("");
 }
 
-void lookup_gtabn(char *ch)
+void lookup_gtabn(char *ch, char *out)
 {
-  char out[512];
+  char outbuf[512];
   char *tbuf[128];
   int tbufN=0;
   INMD *tinmd = &inmd[default_input_method];
@@ -130,6 +130,17 @@ void lookup_gtabn(char *ch)
   if (!tinmd)
     return;
 
+  gboolean need_disp = FALSE;
+
+  if (!out) {
+    out = outbuf;
+    need_disp = TRUE;
+  }
+
+  out[0]=0;
+
+  int min_klen = 100;
+
   int i;
   for(i=0; i < tinmd->DefChars; i++) {
     char *chi = tblch2(tinmd, i);
@@ -152,7 +163,7 @@ void lookup_gtabn(char *ch)
 
     int j;
 
-    int tlen=0;
+    int tlen=0, klen=0;
     char t[CH_SZ * MAX_TAB_KEY_NUM64 + 1];
 
     for(j=Max_tab_key_num1(tinmd) - 1; j>=0; j--) {
@@ -175,8 +186,12 @@ void lookup_gtabn(char *ch)
 //      dbg("uuuuuuuuuuuu %d %x len:%d\n", k, tinmd->keyname[k], len);
       memcpy(&t[tlen], keyname, len);
       tlen+=len;
+      klen++;
     }
 
+    if (klen < min_klen)
+      min_klen = klen;
+
     t[tlen]=0;
 
     tbuf[tbufN] = strdup(t);
@@ -198,10 +213,11 @@ void lookup_gtabn(char *ch)
     free(tbuf[i]);
   }
 
-  if (!out[0])
+  if (!out[0] || !need_disp)
     return;
 
-  set_key_codes_label(out);
+
+  set_key_codes_label(out, ci > min_klen);
   void set_key_codes_label_pho(char *s);
   set_key_codes_label_pho(out);
 }
@@ -210,10 +226,17 @@ void lookup_gtab(char *ch)
 {
   char tt[CH_SZ+1];
   utf8cpy(tt, ch);
-  lookup_gtabn(tt);
+  lookup_gtabn(tt, NULL);
 }
 
 
+void lookup_gtab_out(char *ch, char *out)
+{
+  char tt[CH_SZ+1];
+  utf8cpy(tt, ch);
+  lookup_gtabn(tt, out);
+}
+
 void free_gtab()
 {
   int i;
@@ -630,11 +653,13 @@ static void putstr_inp(u_char *p)
   clear_page_label();
 
   if (!wild_mode && gtab_hide_row2 || !gtab_disp_key_codes)
-    set_key_codes_label(NULL);
+    set_key_codes_label(NULL, 0);
+
+  char_play(p);
 
   if (utf8_str_N(p) > 1  || p[0] < 128) {
     if (gtab_disp_key_codes && !gtab_hide_row2 || wild_mode)
-      lookup_gtabn(p);
+      lookup_gtabn(p, NULL);
 
     send_text(p);
   }
@@ -1309,6 +1334,8 @@ direct_select:
 
       break;
     case '?':
+      if (!gtab_que_wild_card)
+        return 0;
     case '*':
       if (ci< cur_inmd->MaxPress) {
         inkey=cur_inmd->keymap[key];
