@@ -25,7 +25,8 @@ extern char tsidxfname[64];
 extern int hashidx[TSIN_HASH_N];
 
 CHPHO chpho[MAX_PH_BF_EXT];
-int c_idx, c_len;
+int c_idx;
+extern int c_len;
 int ph_sta=-1, ph_sta_last=-1;  // phrase start
 static int sel_pho;
 static gboolean eng_ph=TRUE;  // english(FALSE) <-> pho(juyin, TRUE)
@@ -133,7 +134,7 @@ static void chpho_extract(CHPHO *chph, int len, phokey_t *pho, char *ch, char *o
 void inc_pho_count(phokey_t key, int ch_idx);
 int ch_key_to_ch_pho_idx(phokey_t phkey, char *big5);
 void inc_dec_tsin_use_count(phokey_t *pho, char *ch, int prlen, int N);
-void lookup_gtabn(char *ch);
+void lookup_gtabn(char *ch, char *);
 
 static void putbuf(int len)
 {
@@ -203,7 +204,7 @@ static void putbuf(int len)
 
   tt[idx]=0;
   send_text(tt);
-  lookup_gtabn(tt);
+  lookup_gtabn(tt, NULL);
 }
 
 
@@ -1180,13 +1181,7 @@ static gboolean pre_punctuation_hsu(KeySym xkey)
 gboolean inph_typ_pho(char newkey);
 
 
-gint64 current_time()
-{
-  struct timeval tval;
-
-  gettimeofday(&tval, NULL);
-  return (gint64)tval.tv_sec * 1000000 + tval.tv_usec;
-}
+gint64 current_time();
 
 static void call_tsin_parse()
 {
@@ -1196,17 +1191,35 @@ static void call_tsin_parse()
   prbuf();
 }
 
-void case_inverse(int *xkey, int shift_m)
+static KeySym keypad_proc(KeySym xkey)
 {
-  if (shift_m) {
-    if (islower(*xkey))
-      *xkey-=0x20;
-  } else
-  if (isupper(*xkey))
-    *xkey+=0x20;
+  if (xkey <= XK_KP_9 && xkey >= XK_KP_0)
+    xkey=xkey-XK_KP_0+'0';
+  else {
+    switch (xkey) {
+      case XK_KP_Add:
+        xkey = '+';
+        break;
+      case XK_KP_Subtract:
+        xkey = '-';
+        break;
+      case XK_KP_Multiply:
+        xkey = '*';
+        break;
+      case XK_KP_Divide:
+        xkey = '/';
+        break;
+    }
+  }
+
+  return xkey;
 }
 
 
+void case_inverse();
+
+void pho_play(phokey_t key);
+
 int feedkey_pp(KeySym xkey, int kbstate)
 {
   char ctyp=0;
@@ -1470,12 +1483,9 @@ tab_phrase_end:
          return 1;
        }
 
-       if (tsin_space_opt == TSIN_SPACE_OPT_FLUSH_BUFFER) {
-         if (c_len && eng_ph
-           && (ityp3_pho || (!typ_pho[0] && !typ_pho[1] && !typ_pho[2])) ) {
-           flush_tsin_buffer();
-           return 1;
-         }
+       if (tsin_space_opt == TSIN_SPACE_OPT_INPUT && !typ_pho[0] && !typ_pho[1] && !typ_pho[2] && !ityp3_pho && !sel_pho) {
+         close_selection_win();
+         goto asc_char;
        }
      case XK_Down:
        if (!eng_ph && xkey == XK_space)
@@ -1541,6 +1551,9 @@ other_keys:
        if ('A' <= xkey && xkey <= 'Z')
           xkey_lcase = tolower(xkey);
 
+       if (tsin_space_opt == TSIN_SPACE_OPT_INPUT)
+         xkey_lcase = keypad_proc(xkey);
+
        if ((pp=strchr(phkbm.selkey,xkey_lcase)) && sel_pho) {
          int c=pp-phkbm.selkey;
          char *sel_text;
@@ -1613,6 +1626,8 @@ other_keys:
         xkey == XK_KP_Subtract || xkey == XK_KP_Add || xkey == XK_KP_Multiply ||
         xkey == XK_KP_Divide
        ) {
+
+       xkey = keypad_proc(xkey);
 asc_char:
         if (shift_m) {
           if (pre_sel_handler(xkey)) {
@@ -1623,24 +1638,6 @@ asc_char:
             return 1;
         }
 
-        if (xkey <= XK_KP_9 && xkey >= XK_KP_0)
-          xkey=xkey-XK_KP_0+'0';
-        else {
-          switch (xkey) {
-            case XK_KP_Add:
-              xkey = '+';
-              break;
-            case XK_KP_Subtract:
-              xkey = '-';
-              break;
-            case XK_KP_Multiply:
-              xkey = '*';
-              break;
-            case XK_KP_Divide:
-              xkey = '/';
-              break;
-          }
-        }
 
 //        dbg("xkey: %c\n", xkey);
 
@@ -1732,6 +1729,8 @@ llll2:
 
      key = pho2key(typ_pho);
 
+     pho_play(key);
+
      int vv=hash_pho[typ_pho[0]];
      phokey_t ttt=0xffff;
      while (vv<idxnum_pho) {
