@@ -17,6 +17,7 @@ static GtkWidget *image_pin;
 static GtkWidget *box_gtab_im_name;
 static GtkWidget *hbox_row2;
 static GtkWidget *label_page;
+static GdkColor better_color;
 
 Window xwin_gtab;
 void set_label_space(GtkWidget *label);
@@ -161,7 +162,7 @@ void disp_gtab_sel(char *s)
 }
 
 
-void set_key_codes_label(char *s)
+void set_key_codes_label(char *s, int better)
 {
   if (!label_key_codes)
     return;
@@ -174,6 +175,11 @@ void set_key_codes_label(char *s)
     }
   }
 
+  if (better)
+    gtk_widget_modify_fg(label_key_codes, GTK_STATE_NORMAL, &better_color);
+  else
+    gtk_widget_modify_fg(label_key_codes, GTK_STATE_NORMAL, NULL);
+
   gtk_label_set_text(GTK_LABEL(label_key_codes), s);
 }
 
@@ -337,7 +343,7 @@ void create_win_gtab_gui_full()
 
   if (left_right_button_tips) {
     GtkTooltips *button_gtab_tips = gtk_tooltips_new ();
-    gtk_tooltips_set_tip (GTK_TOOLTIPS (button_gtab_tips), button_gtab, "左鍵符號，右鍵設定",NULL);
+    gtk_tooltips_set_tip (GTK_TOOLTIPS (button_gtab_tips), button_gtab, _("左鍵符號，右鍵設定"),NULL);
   }
 
   GtkWidget *hbox_gtab = gtk_hbox_new (FALSE, 0);
@@ -391,7 +397,7 @@ void create_win_gtab_gui_simple()
     top_bin = vbox_top;
   }
 
-  GtkWidget *align = gtk_alignment_new (0, 0, 0, 0);
+  GtkWidget *align = gtk_alignment_new (0, 0.0, 0, 0);
 
   label_gtab_sele = gtk_label_new(NULL);
   gtk_container_add (GTK_CONTAINER (align), label_gtab_sele);
@@ -444,7 +450,7 @@ void create_win_gtab_gui_simple()
 
   if (left_right_button_tips) {
     GtkTooltips *button_gtab_tips = gtk_tooltips_new ();
-    gtk_tooltips_set_tip (GTK_TOOLTIPS (button_gtab_tips), event_box_gtab, "左鍵符號，右鍵設定",NULL);
+    gtk_tooltips_set_tip (GTK_TOOLTIPS (button_gtab_tips), event_box_gtab, _("左鍵符號，右鍵設定"),NULL);
   }
 
   GtkWidget *hbox_gtab = gtk_hbox_new (FALSE, 0);
@@ -462,7 +468,6 @@ void create_win_gtab_gui_simple()
 //    set_label_font_family(label, "serif");
   }
 
-
   label_key_codes  = gtk_label_new(NULL);
   gtk_label_set_selectable(GTK_LABEL(label_key_codes), TRUE);
   gtk_box_pack_start (GTK_BOX (hbox_row2), label_key_codes, FALSE, FALSE, 2);
@@ -498,6 +503,7 @@ static void create_win_gtab_gui()
   current_gtab_in_row1 = gtab_in_row1;
   current_gtab_vertical_select = gtab_vertical_select;
   current_gcin_inner_frame = gcin_inner_frame;
+  gdk_color_parse("yellow", &better_color);
 }
 
 
