@@ -57,7 +57,6 @@ static GtkWidget *create_int_opts()
   for(i=0; i < int_selN; i++) {
     GtkWidget *item = gtk_menu_item_new_with_label (int_sel[i].name);
 
-
     gtk_menu_shell_append (GTK_MENU_SHELL (menu_int_opts), item);
   }
 
@@ -149,7 +148,7 @@ void create_win_intcode()
   gtk_widget_realize (gwin_int);
   GdkWindow *gdkwin = gwin_int->window;
 
-  gdk_window_set_override_redirect(gdkwin, TRUE);
+  set_no_focus(gwin_int);
 
   GtkWidget *frame = gtk_frame_new(NULL);
   gtk_container_set_border_width (GTK_CONTAINER (frame), 0);
